# Object model

Launchable's object model includes concepts that reflect objects in your development/CI environment (like [build.md](build.md "mention") and [test-session.md](test-session.md "mention")) alongside added-value concepts like [subset.md](subset.md "mention") and [insight.md](insight.md "mention").

The diagram below outlines the relationship between objects. Items in bold are key concepts that have their own pages containing additional explanation.

![Launchable object model](<../.gitbook/assets/Object model June 2022@2x (1).png>)

To learn more, check out:

* [organization.md](organization.md "mention")
* [workspace.md](workspace.md "mention")
* [build.md](build.md "mention")
* [test-session.md](test-session.md "mention")
* [subset.md](subset.md "mention")
* [insight.md](insight.md "mention")
